package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.OrderComment;
import com.ruoyi.system.service.IOrderCommentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单评价Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/OrderComment")
public class OrderCommentController extends BaseController
{
    @Autowired
    private IOrderCommentService orderCommentService;

    /**
     * 查询订单评价列表
     */
    @PreAuthorize("@ss.hasPermi('system:OrderComment:list')")
    @GetMapping("/list")
    public TableDataInfo list(OrderComment orderComment)
    {
        startPage();
        List<OrderComment> list = orderCommentService.selectOrderCommentList(orderComment);
        return getDataTable(list);
    }

    /**
     * 导出订单评价列表
     */
    @PreAuthorize("@ss.hasPermi('system:OrderComment:export')")
    @Log(title = "订单评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OrderComment orderComment)
    {
        List<OrderComment> list = orderCommentService.selectOrderCommentList(orderComment);
        ExcelUtil<OrderComment> util = new ExcelUtil<OrderComment>(OrderComment.class);
        util.exportExcel(response, list, "订单评价数据");
    }

    /**
     * 获取订单评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:OrderComment:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(orderCommentService.selectOrderCommentById(id));
    }

    /**
     * 新增订单评价
     */
    @PreAuthorize("@ss.hasPermi('system:OrderComment:add')")
    @Log(title = "订单评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OrderComment orderComment)
    {
        return toAjax(orderCommentService.insertOrderComment(orderComment));
    }

    /**
     * 修改订单评价
     */
    @PreAuthorize("@ss.hasPermi('system:OrderComment:edit')")
    @Log(title = "订单评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OrderComment orderComment)
    {
        return toAjax(orderCommentService.updateOrderComment(orderComment));
    }

    /**
     * 删除订单评价
     */
    @PreAuthorize("@ss.hasPermi('system:OrderComment:remove')")
    @Log(title = "订单评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(orderCommentService.deleteOrderCommentByIds(ids));
    }
}
